Units

Enum Units 

#[non_exhaustive]
pub enum Units {
Show 55 variants square_yottameter, square_zettameter, square_exameter, square_petameter, square_terameter, square_gigameter, square_megameter, square_kilometer, square_hectometer, square_decameter, square_meter, square_decimeter, square_centimeter, square_millimeter, square_micrometer, square_nanometer, square_picometer, square_femtometer, square_attometer, square_zeptometer, square_yoctometer, acre, are, barn, circular_mil, hectare, square_foot, square_inch, square_mile, square_yard, saltus, centuria, heredium, jugerum, deunx, dextans, dodrans, bes, septunx, semis, actus_quadratus, quincunx, triens, quadrans, sextans, clima, uncia, semiuncia, sicilicus, actus_simplex, sextula, duo_scrupulum, scrupulum, dimidium_scrupulum, pes_quadratus,
}
Unit enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


square_yottameter

square yottameters



square_zettameter

square zettameters



square_exameter

square exameters



square_petameter

square petameters



square_terameter

square terameters



square_gigameter

square gigameters



square_megameter

square megameters



square_kilometer

square kilometers



square_hectometer

square hectometers



square_decameter

square decameters



square_meter

square meters



square_decimeter

square decimeters



square_centimeter

square centimeters



square_millimeter

square millimeters



square_micrometer

square micrometers



square_nanometer

square nanometers



square_picometer

square picometers



square_femtometer

square femtometers



square_attometer

square attometers



square_zeptometer

square zeptometers



square_yoctometer

square yoctometers



acre

acres



are

ares



barn

barns



circular_mil

circular mils



hectare

hectares



square_foot

square feet



square_inch

square inches



square_mile

square miles



square_yard

square yards



saltus

saltus



centuria

centuriae



heredium

heredia



jugerum

jugera



deunx

deunces



dextans

dextantes



dodrans

dodrantes



bes

besses



septunx

septunces



semis

semisses



actus_quadratus

acta quadratus



quincunx

quincunces



triens

trientes



quadrans

quadrantes



sextans

sextantes



clima

climata



uncia

unciae



semiuncia

semiunciae



sicilicus

siculi



actus_simplex

acta simplex



sextula

sextulae



duo_scrupulum

duo scrupula



scrupulum

scrupula



dimidium_scrupulum

dimidium scupula



pes_quadratus

pedes quadratus

Implementations



impl Units

pub fn abbreviation(&self) -> &'static str

Unit abbreviation.

pub fn singular(&self) -> &'static str

Unit singular description.

pub fn plural(&self) -> &'static str

Unit plural description.