Units

Enum Units 

#[non_exhaustive]
pub enum Units {
Show 48 variants yottakatal, zettakatal, exakatal, petakatal, terakatal, gigakatal, megakatal, kilokatal, hectokatal, decakatal, katal, decikatal, centikatal, millikatal, microkatal, nanokatal, picokatal, femtokatal, attokatal, zeptokatal, yoctokatal, yotta_enzyme_unit, zetta_enzyme_unit, exa_enzyme_unit, peta_enzyme_unit, tera_enzyme_unit, giga_enzyme_unit, mega_enzyme_unit, kilo_enzyme_unit, hecto_enzyme_unit, deca_enzyme_unit, enzyme_unit, deci_enzyme_unit, centi_enzyme_unit, milli_enzyme_unit, micro_enzyme_unit, nano_enzyme_unit, pico_enzyme_unit, femto_enzyme_unit, atto_enzyme_unit, zepto_enzyme_unit, yocto_enzyme_unit, particle_per_second, mole_per_second, standard_centimeter_per_minute, standard_liter_per_minute, standard_cubic_meter_per_minute, standard_cubic_foot_per_minute,
}
Unit enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


yottakatal

yottakatals



zettakatal

zettakatals



exakatal

exakatals



petakatal

petakatals



terakatal

terakatals



gigakatal

gigakatals



megakatal

megakatals



kilokatal

kilokatals



hectokatal

hectokatals



decakatal

decakatals



katal

katals



decikatal

decikatals



centikatal

centikatals



millikatal

millikatals



microkatal

microkatals



nanokatal

nanokatals



picokatal

picokatals



femtokatal

femtokatals



attokatal

attokatals



zeptokatal

zeptokatals



yoctokatal

yoctokatals



yotta_enzyme_unit

yotta enzyme units



zetta_enzyme_unit

zetta enzyme units



exa_enzyme_unit

exa enzyme units



peta_enzyme_unit

peta enzyme units



tera_enzyme_unit

tera enzyme units



giga_enzyme_unit

giga enzyme units



mega_enzyme_unit

mega enzyme units



kilo_enzyme_unit

kilo enzyme units



hecto_enzyme_unit

hecto enzyme units



deca_enzyme_unit

deca enzyme units



enzyme_unit

enzyme units



deci_enzyme_unit

deci enzyme units



centi_enzyme_unit

centi enzyme units



milli_enzyme_unit

milli enzyme units



micro_enzyme_unit

micro enzyme units



nano_enzyme_unit

nano enzyme units



pico_enzyme_unit

pico enzyme units



femto_enzyme_unit

femto enzyme units



atto_enzyme_unit

atto enzyme units



zepto_enzyme_unit

zepto enzyme units



yocto_enzyme_unit

yocto enzyme units



particle_per_second

particles per second



mole_per_second

moles per second



standard_centimeter_per_minute

standard centimeters per minute



standard_liter_per_minute

standard liters per minute



standard_cubic_meter_per_minute

standard cubic meters per minute



standard_cubic_foot_per_minute

standard cubic feet per hour

Implementations



impl Units

pub fn abbreviation(&self) -> &'static str

Unit abbreviation.

pub fn singular(&self) -> &'static str

Unit singular description.

pub fn plural(&self) -> &'static str

Unit plural description.