Units

Enum Units 

#[non_exhaustive]
pub enum Units {
Show 37 variants yottacoulomb, zettacoulomb, exacoulomb, petacoulomb, teracoulomb, gigacoulomb, megacoulomb, kilocoulomb, hectocoulomb, decacoulomb, coulomb, decicoulomb, centicoulomb, millicoulomb, microcoulomb, nanocoulomb, picocoulomb, femtocoulomb, attocoulomb, zeptocoulomb, yoctocoulomb, petaampere_hour, teraampere_hour, gigaampere_hour, megaampere_hour, kiloampere_hour, hectoampere_hour, decaampere_hour, ampere_hour, milliampere_hour, microampere_hour, elementary_charge, atomic_unit_of_charge, abcoulomb, faraday, franklin, statcoulomb,
}
Unit enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


yottacoulomb

yottacoulombs



zettacoulomb

zettacoulombs



exacoulomb

exacoulombs



petacoulomb

petacoulombs



teracoulomb

teracoulombs



gigacoulomb

gigacoulombs



megacoulomb

megacoulombs



kilocoulomb

kilocoulombs



hectocoulomb

hectocoulombs



decacoulomb

decacoulombs



coulomb

coulombs



decicoulomb

decicoulombs



centicoulomb

centicoulombs



millicoulomb

millcoulombs



microcoulomb

microcoulombs



nanocoulomb

nanocoulombs



picocoulomb

picocoulombs



femtocoulomb

femtocoulombs



attocoulomb

attocoulombs



zeptocoulomb

zeptocoulombs



yoctocoulomb

yoctocoulombs



petaampere_hour

petaampere hours



teraampere_hour

teraampere hours



gigaampere_hour

gigaampere hours



megaampere_hour

megaampere hours



kiloampere_hour

kiloampere hours



hectoampere_hour

hectoampere hours



decaampere_hour

decaampere hours



ampere_hour

ampere hours



milliampere_hour

milliampere hours



microampere_hour

microampere hours



elementary_charge

elementary charges



atomic_unit_of_charge

atomic units of charge



abcoulomb

abcoulombs



faraday

faradays



franklin

franklins



statcoulomb

statcoulombs

Implementations



impl Units

pub fn abbreviation(&self) -> &'static str

Unit abbreviation.

pub fn singular(&self) -> &'static str

Unit singular description.

pub fn plural(&self) -> &'static str

Unit plural description.