Units

Enum Units 

#[non_exhaustive]
pub enum Units {
Show 26 variants yottaampere, zettaampere, exaampere, petaampere, teraampere, gigaampere, megaampere, kiloampere, hectoampere, decaampere, ampere, deciampere, centiampere, milliampere, microampere, nanoampere, picoampere, femtoampere, attoampere, zeptoampere, yoctoampere, elementary_charge_per_second, atomic_unit_of_charge_per_second, abampere, gilbert, statampere,
}
Unit enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


yottaampere

yottaamperes



zettaampere

zettaamperes



exaampere

exaamperes



petaampere

petaamperes



teraampere

teraamperes



gigaampere

gigaamperes



megaampere

megaamperes



kiloampere

kiloamperes



hectoampere

hectoamperes



decaampere

decaamperes



ampere

amperes



deciampere

deciamperes



centiampere

centiamperes



milliampere

millamperes



microampere

microamperes



nanoampere

nanoamperes



picoampere

picoamperes



femtoampere

femtoamperes



attoampere

attoamperes



zeptoampere

zeptoamperes



yoctoampere

yoctoamperes



elementary_charge_per_second

elementary charges per second



atomic_unit_of_charge_per_second

atomic units of charge per second



abampere

abamperes



gilbert

gilberts



statampere

statamperes

Implementations



impl Units

pub fn abbreviation(&self) -> &'static str

Unit abbreviation.

pub fn singular(&self) -> &'static str

Unit singular description.

pub fn plural(&self) -> &'static str

Unit plural description.