Units

Enum Units 

#[non_exhaustive]
pub enum Units {
Show 61 variants yottajoule, zettajoule, exajoule, petajoule, terajoule, gigajoule, megajoule, kilojoule, hectojoule, decajoule, joule, decijoule, centijoule, millijoule, microjoule, nanojoule, picojoule, femtojoule, attojoule, zeptojoule, yoctojoule, petawatt_hour, terawatt_hour, gigawatt_hour, megawatt_hour, kilowatt_hour, hectowatt_hour, decawatt_hour, watt_hour, milliwatt_hour, microwatt_hour, petaelectronvolt, teraelectronvolt, gigaelectronvolt, megaelectronvolt, kiloelectronvolt, hectoelectronvolt, decaelectronvolt, electronvolt, hartree, btu_it, btu, btu_39, btu_59, btu_60, calorie_it, calorie, calorie_15, calorie_20, calorie_it_nutrition, calorie_nutrition, erg, foot_poundal, foot_pound, kilocalorie_it, kilocalorie, quad, therm_ec, therm_us, ton_tnt, watt_second,
}
Unit enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


yottajoule

yottajoules



zettajoule

zettajoules



exajoule

exajoules



petajoule

petajoules



terajoule

terajoules



gigajoule

gigajoules



megajoule

megajoules



kilojoule

kilojoules



hectojoule

hectojoules



decajoule

decajoules



joule

joules



decijoule

decijoules



centijoule

centijoules



millijoule

millijoules



microjoule

microjoules



nanojoule

nanojoules



picojoule

picojoules



femtojoule

femtojoules



attojoule

attojoules



zeptojoule

zeptojoules



yoctojoule

yoctojoules



petawatt_hour

petawatt hours



terawatt_hour

terawatt hours



gigawatt_hour

gigawatt hours



megawatt_hour

megawatt hours



kilowatt_hour

kilowatt hours



hectowatt_hour

hectowatt hours



decawatt_hour

decawatt hours



watt_hour

watt hours



milliwatt_hour

milliwatt hours



microwatt_hour

microwatt hours



petaelectronvolt

petaelectronvolts



teraelectronvolt

teraelectronvolts



gigaelectronvolt

gigaelectronvolts



megaelectronvolt

megaelectronvolts



kiloelectronvolt

kiloelectronvolts



hectoelectronvolt

hectoelectronvolts



decaelectronvolt

decaelectronvolts



electronvolt

electronvolts



hartree

hartrees



btu_it

British thermal units (IT)



btu

British thermal units



btu_39

British thermal units (39 °F)



btu_59

British thermal units (59 °F)



btu_60

British thermal units (60 °F)



calorie_it

calories (IT)



calorie

calories



calorie_15

calories (15 °C)



calorie_20

calories (20 °C)



calorie_it_nutrition

Calories (IT)



calorie_nutrition

Calories



erg

ergs



foot_poundal

foot poundals



foot_pound

foot pounds-force



kilocalorie_it

kilocalories (IT)



kilocalorie

kilocalories



quad

quads



therm_ec

therms (EC)



therm_us

therms



ton_tnt

tons of TNT



watt_second

watt seconds

Implementations



impl Units

pub fn abbreviation(&self) -> &'static str

Unit abbreviation.

pub fn singular(&self) -> &'static str

Unit singular description.

pub fn plural(&self) -> &'static str

Unit plural description.