TemperatureCoefficient

Struct TemperatureCoefficient 

pub struct TemperatureCoefficient(/* private fields */);

Implementations

Source

impl TemperatureCoefficient

pub fn new<U>(value: f64) -> Self
where U: Conversion<f64>,

pub fn get<U>(&self) -> f64
where U: Conversion<f64>,

pub fn raw(&self) -> f64

pub fn into_uom(self) -> TemperatureCoefficient

pub fn as_uom(&self) -> &TemperatureCoefficient

pub fn from_uom(inner: TemperatureCoefficient) -> Self

Methods from Deref<Target = TemperatureCoefficient>

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub const HALF_TURN: Quantity<dyn Dimension<M = Z0, J = Z0, I = Z0, L = Z0, Th = Z0, T = Z0, Kind = dyn AngleKind, N = Z0>, dyn Units<f32, luminous_intensity = candela, thermodynamic_temperature = kelvin, amount_of_substance = mole, electric_current = ampere, mass = kilogram, length = meter, time = second>, f32>

pub const FULL_TURN: Quantity<dyn Dimension<M = Z0, J = Z0, I = Z0, L = Z0, Th = Z0, T = Z0, Kind = dyn AngleKind, N = Z0>, dyn Units<f32, luminous_intensity = candela, thermodynamic_temperature = kelvin, amount_of_substance = mole, electric_current = ampere, mass = kilogram, length = meter, time = second>, f32>

pub const HALF_TURN: Quantity<dyn Dimension<M = Z0, J = Z0, I = Z0, L = Z0, Th = Z0, T = Z0, Kind = dyn AngleKind, N = Z0>, dyn Units<f64, luminous_intensity = candela, thermodynamic_temperature = kelvin, amount_of_substance = mole, electric_current = ampere, mass = kilogram, length = meter, time = second>, f64>

pub const FULL_TURN: Quantity<dyn Dimension<M = Z0, J = Z0, I = Z0, L = Z0, Th = Z0, T = Z0, Kind = dyn AngleKind, N = Z0>, dyn Units<f64, luminous_intensity = candela, thermodynamic_temperature = kelvin, amount_of_substance = mole, electric_current = ampere, mass = kilogram, length = meter, time = second>, f64>

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub const SPHERE: Quantity<dyn Dimension<M = Z0, J = Z0, I = Z0, L = Z0, Th = Z0, T = Z0, Kind = dyn SolidAngleKind, N = Z0>, dyn Units<f32, luminous_intensity = candela, thermodynamic_temperature = kelvin, amount_of_substance = mole, electric_current = ampere, mass = kilogram, length = meter, time = second>, f32>

pub const SPHERE: Quantity<dyn Dimension<M = Z0, J = Z0, I = Z0, L = Z0, Th = Z0, T = Z0, Kind = dyn SolidAngleKind, N = Z0>, dyn Units<f64, luminous_intensity = candela, thermodynamic_temperature = kelvin, amount_of_substance = mole, electric_current = ampere, mass = kilogram, length = meter, time = second>, f64>

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.