HeatTransfer

Type Alias HeatTransfer 

pub type HeatTransfer<U, V> = Quantity<dyn Dimension<M = PInt<UInt<UTerm, B1>>, J = Z0, I = Z0, L = Z0, Th = NInt<UInt<UTerm, B1>>, T = NInt<UInt<UInt<UTerm, B1>, B1>>, Kind = dyn Kind, N = Z0>, U, V>;
Heat transfer (base unit watt per square meter kelvin, kg · s⁻³ · K⁻¹).

Generic Parameters

  • U: Base units.
  • V: Underlying storage type.

Aliased Type

#[repr(transparent)]
pub struct HeatTransfer<U, V> { pub dimension: PhantomData<dyn Dimension<M = PInt<UInt<UTerm, B1>>, J = Z0, I = Z0, L = Z0, Th = NInt<UInt<UTerm, B1>>, T = NInt<UInt<UInt<UTerm, B1>, B1>>, Kind = dyn Kind, N = Z0>>, pub units: PhantomData<U>, pub value: V, }

Fields

dimension: PhantomData<dyn Dimension<M = PInt<UInt<UTerm, B1>>, J = Z0, I = Z0, L = Z0, Th = NInt<UInt<UTerm, B1>>, T = NInt<UInt<UInt<UTerm, B1>, B1>>, Kind = dyn Kind, N = Z0>>

Quantity dimension. See [Dimension].

units: PhantomData<U>

Quantity base units. See [Units].

value: V

Quantity value stored in the base units for the quantity.