Units

Enum Units 

#[non_exhaustive]
pub enum Units {
Show 42 variants yobibit, yottabit, zebibit, zettabit, exbibit, exabit, pebibit, petabit, tebibit, terabit, gibibit, gigabit, mebibit, megabit, kibibit, kilobit, bit, yobibyte, yottabyte, zebibyte, zettabyte, exbibyte, exabyte, pebibyte, petabyte, tebibyte, terabyte, gibibyte, gigabyte, mebibyte, megabyte, kibibyte, kilobyte, byte, octet, nibble, crumb, shannon, natural_unit_of_information, trit, hartley, deciban,
}
Unit enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


yobibit

yobibits



yottabit

yottabits



zebibit

zebibits



zettabit

zettabits



exbibit

exbibits



exabit

exabits



pebibit

pebibits



petabit

petabits



tebibit

tibibits



terabit

terabits



gibibit

gibibits



gigabit

gigabits



mebibit

mebibits



megabit

megabits



kibibit

kibibits



kilobit

kilobits



bit

bits



yobibyte

yobibytes



yottabyte

yottabytes



zebibyte

zebibytes



zettabyte

zettabytes



exbibyte

exbibytes



exabyte

exabytes



pebibyte

pebibytes



petabyte

petabytes



tebibyte

tibibytes



terabyte

terabytes



gibibyte

gibibytes



gigabyte

gigabytes



mebibyte

mebibytes



megabyte

megabytes



kibibyte

kibibytes



kilobyte

kilobytes



byte

bytes



octet

octets



nibble

nibbles



crumb

crumbs



shannon

shannons



natural_unit_of_information

natural units of information



trit

trits



hartley

hartleys



deciban

decibans

Implementations



impl Units

pub fn abbreviation(&self) -> &'static str

Unit abbreviation.

pub fn singular(&self) -> &'static str

Unit singular description.

pub fn plural(&self) -> &'static str

Unit plural description.