Units

Enum Units 

#[non_exhaustive]
pub enum Units {
Show 60 variants yottameter, zettameter, exameter, petameter, terameter, gigameter, megameter, kilometer, hectometer, decameter, meter, decimeter, centimeter, millimeter, micrometer, nanometer, picometer, femtometer, attometer, zeptometer, yoctometer, angstrom, bohr_radius, atomic_unit_of_length, astronomical_unit, chain, data_mile, fathom, fermi, foot, foot_survey, inch, light_year, microinch, micron, mil, mile, mile_survey, nautical_mile, parsec, pica_computer, pica_printers, point_computer, point_printers, rod, yard, leuga, mille_passus, stadium, actus, decempeda, passus, gradus, cubitum, palmipes, pes, palmus_maior, palmus, uncia, digitus,
}
Unit enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


yottameter

yottameters



zettameter

zettameters



exameter

exameters



petameter

petameters



terameter

terameters



gigameter

gigameters



megameter

megameters



kilometer

kilometers



hectometer

hectometers



decameter

decameters



meter

meters



decimeter

decimeters



centimeter

centimeters



millimeter

millimeters



micrometer

micrometers



nanometer

nanometers



picometer

picometers



femtometer

femtometers



attometer

attometers



zeptometer

zeptometers



yoctometer

yoctometers



angstrom

ångströms



bohr_radius

bohr radiuses



atomic_unit_of_length

atomic units of length



astronomical_unit

astronomical units



chain

chains



data_mile

data miles



fathom

fathoms



fermi

fermis



foot

feet



foot_survey

feet (U.S. survey)



inch

inches



light_year

light years



microinch

microinches



micron

microns



mil

mils



mile

miles



mile_survey

miles (U.S. survey)



nautical_mile

nautical miles



parsec

parsecs



pica_computer

picas (computer)



pica_printers

picas (printer’s)



point_computer

points (computer)



point_printers

points (printer’s)



rod

rods



yard

yards



leuga

leugae



mille_passus

mille passa



stadium

stadia



actus

acta



decempeda

decempedae



passus

passa



gradus

gradus



cubitum

cubita



palmipes

palmipedes



pes

pedes



palmus_maior

palmas maior



palmus

palmas



uncia

unciae



digitus

digiti

Implementations



impl Units

pub fn abbreviation(&self) -> &'static str

Unit abbreviation.

pub fn singular(&self) -> &'static str

Unit singular description.

pub fn plural(&self) -> &'static str

Unit plural description.