Units

Enum Units 

#[non_exhaustive]
pub enum Units {
Show 57 variants yottagram, zettagram, exagram, petagram, teragram, gigagram, megagram, kilogram, hectogram, decagram, gram, decigram, centigram, milligram, microgram, nanogram, picogram, femtogram, attogram, zeptogram, yoctogram, carat, dalton, grain, hundredweight_long, hundredweight_short, ounce, ounce_troy, pennyweight, pound, pound_troy, slug, ton_assay, ton_long, ton_short, ton, libra, deunx, dextans, dodrans, bes, septunx, semis, quincunx, triens, quadrans_teruncius, sextans, sescuncia, uncia, semuncia, duella, sicilicus, sextula, semisextula, scrupulum, obolus, siliqua,
}
Unit enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


yottagram

yottagrams



zettagram

zettagrams



exagram

exagrams



petagram

petagrams



teragram

teragrams



gigagram

gigagrams



megagram

megagrams



kilogram

kilograms



hectogram

hectograms



decagram

decagrams



gram

grams



decigram

decigrams



centigram

centigrams



milligram

milligrams



microgram

micrograms



nanogram

nanograms



picogram

picograms



femtogram

femtograms



attogram

attograms



zeptogram

zeptograms



yoctogram

yoctograms



carat

carats



dalton

daltons



grain

grains



hundredweight_long

hundredweight (long)



hundredweight_short

hundredweight (short)



ounce

ounces



ounce_troy

troy ounces



pennyweight

pennyweight



pound

pounds



pound_troy

troy pounds



slug

slugs



ton_assay

assay tons



ton_long

long tons



ton_short

short tons



ton

tons



libra

librae



deunx

deunces



dextans

dextantes



dodrans

dodrantes



bes

bessis



septunx

septunces



semis

semisses



quincunx

quincunx



triens

trientes



quadrans_teruncius

quadrantes teruncius



sextans

sextantes



sescuncia

sescunciae



uncia

unciae



semuncia

semunciae



duella

duella



sicilicus

scilici



sextula

sextulae



semisextula

semisextulae



scrupulum

scrupula



obolus

oboli



siliqua

siliquae

Implementations



impl Units

pub fn abbreviation(&self) -> &'static str

Unit abbreviation.

pub fn singular(&self) -> &'static str

Unit singular description.

pub fn plural(&self) -> &'static str

Unit plural description.