Units

Enum Units 

#[non_exhaustive]
pub enum Units {
Show 53 variants yottapascal, zettapascal, exapascal, petapascal, terapascal, gigapascal, megapascal, kilopascal, hectopascal, decapascal, pascal, decipascal, centipascal, millipascal, micropascal, nanopascal, picopascal, femtopascal, attopascal, zeptopascal, yoctopascal, kilogram_force_per_square_meter, kilogram_force_per_square_centimeter, gram_force_per_square_centimeter, kilogram_force_per_square_millimeter, atmosphere, atmosphere_technical, bar, centimeter_of_mercury_0, centimeter_of_mercury, centimeter_of_water_4, centimeter_of_water, dyne_per_square_centimeter, foot_of_mercury, foot_of_water_39_2, foot_of_water, inch_of_mercury_32, inch_of_mercury_60, inch_of_mercury, inch_of_water_39_2, inch_of_water_60, inch_of_water, newton_per_square_millimeter, kip_per_square_inch, millibar, millimeter_of_mercury, millimeter_of_water, millitorr, poundal_per_square_foot, pound_force_per_square_foot, pound_force_per_square_inch, psi, torr,
}
Unit enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


yottapascal

yottapascals



zettapascal

zettapascals



exapascal

exapascals



petapascal

petapascals



terapascal

terapascals



gigapascal

gigapascals



megapascal

megapascals



kilopascal

kilopascals



hectopascal

hectopascals



decapascal

decapascals



pascal

pascals



decipascal

decipascals



centipascal

centipascals



millipascal

millipascals



micropascal

micropascals



nanopascal

nanopascals



picopascal

picopascals



femtopascal

femtopascals



attopascal

attopascals



zeptopascal

zeptopascals



yoctopascal

yoctopascals



kilogram_force_per_square_meter

kilograms-force per square meter



kilogram_force_per_square_centimeter

kilograms-force per square centimeter



gram_force_per_square_centimeter

grams-force per square centimeter



kilogram_force_per_square_millimeter

kilograms-force per square millimeter



atmosphere

atmospheres



atmosphere_technical

atmospheres (technical)



bar

bar



centimeter_of_mercury_0

centimeters of mercury (0 °C)



centimeter_of_mercury

centimeters of mercury



centimeter_of_water_4

centimeters of water (4 °C)



centimeter_of_water

centimeters of water



dyne_per_square_centimeter

dynes per square centimeter



foot_of_mercury

feet of mercury



foot_of_water_39_2

feet of water (39.2 °F)



foot_of_water

feet of water



inch_of_mercury_32

inches of mercury (32 °F)



inch_of_mercury_60

inches of mercury (60 °F)



inch_of_mercury

inches of mercury



inch_of_water_39_2

inches of water (39.2 °F)



inch_of_water_60

inches of water (60 °F)



inch_of_water

inches of water



newton_per_square_millimeter

newtons per square millimeter



kip_per_square_inch

kips per square inch



millibar

millibar



millimeter_of_mercury

millimeters of mercury



millimeter_of_water

millimeters of water



millitorr

millitorr



poundal_per_square_foot

poundals per square foot



pound_force_per_square_foot

pounds-force per square foot



pound_force_per_square_inch

pounds-force per square inch



psi

pounds-force per square inch



torr

torr

Implementations



impl Units

pub fn abbreviation(&self) -> &'static str

Unit abbreviation.

pub fn singular(&self) -> &'static str

Unit singular description.

pub fn plural(&self) -> &'static str

Unit plural description.