Enum TryFromError
pub enum TryFromError {
NegativeDuration,
Overflow,
}Expand description
An error encountered converting between Time and Duration.
Variants
NegativeDuration
The given time interval was negative, making conversion to a duration nonsensical.
To convert a negative time interval to a duration, first use abs to make it positive.
Overflow
The given time interval exceeded the maximum size of a Duration.