Units

Enum Units 

#[non_exhaustive]
pub enum Units {
Show 79 variants cubic_yottameter, cubic_zettameter, cubic_exameter, cubic_petameter, cubic_terameter, cubic_gigameter, cubic_megameter, cubic_kilometer, cubic_hectometer, cubic_decameter, cubic_meter, cubic_decimeter, cubic_centimeter, cubic_millimeter, cubic_micrometer, cubic_nanometer, cubic_picometer, cubic_femtometer, cubic_attometer, cubic_zeptometer, cubic_yoctometer, acre_foot, barrel, bushel, cord, cubic_foot, cubic_inch, cubic_mile, cubic_yard, cup, fluid_ounce, fluid_ounce_imperial, gallon_imperial, gallon, gill_imperial, gill, yottaliter, zettaliter, exaliter, petaliter, teraliter, gigaliter, megaliter, kiloliter, hectoliter, decaliter, liter, deciliter, centiliter, milliliter, microliter, nanoliter, picoliter, femtoliter, attoliter, zeptoliter, yoctoliter, peck, pint_dry, pint_liquid, quart_dry, quart_liquid, stere, tablespoon, teaspoon, register_ton, culeus, amphora_quadrantal, urna, modius_castrensis, modius, semimodius, congius, sextarius, hemina, quartarius, acetabulum, cyathus, ligula,
}
Unit enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


cubic_yottameter

cubic yottameters



cubic_zettameter

cubic zettameters



cubic_exameter

cubic exameters



cubic_petameter

cubic petameters



cubic_terameter

cubic terameters



cubic_gigameter

cubic gigameters



cubic_megameter

cubic megameters



cubic_kilometer

cubic kilometers



cubic_hectometer

cubic hectometers



cubic_decameter

cubic decameters



cubic_meter

cubic meters



cubic_decimeter

cubic decimeters



cubic_centimeter

cubic centimeters



cubic_millimeter

cubic millimeters



cubic_micrometer

cubic micrometers



cubic_nanometer

cubic nanometers



cubic_picometer

cubic picometers



cubic_femtometer

cubic femtometers



cubic_attometer

cubic attometers



cubic_zeptometer

cubic zeptometers



cubic_yoctometer

cubic yoctometers



acre_foot

acre-feet



barrel

barrels



bushel

bushels



cord

cords



cubic_foot

cubic feet



cubic_inch

cubic inches



cubic_mile

cubic miles



cubic_yard

cubic yards



cup

cups



fluid_ounce

fluid ounces



fluid_ounce_imperial

Imperial fluid ounces



gallon_imperial

Imperial gallons



gallon

gallons



gill_imperial

Imperial gills



gill

gills



yottaliter

yottaliters



zettaliter

zettaliters



exaliter

exaliters



petaliter

petaliters



teraliter

teraliters



gigaliter

gigaliters



megaliter

megaliters



kiloliter

kiloliters



hectoliter

hectoliters



decaliter

decaliters



liter

liters



deciliter

deciliters



centiliter

centiliters



milliliter

milliliters



microliter

microliters



nanoliter

nanoliters



picoliter

picoliters



femtoliter

femtoliters



attoliter

attoliters



zeptoliter

zeptoliters



yoctoliter

yoctoliters



peck

pecks



pint_dry

dry pints



pint_liquid

liquid pints



quart_dry

dry quarts



quart_liquid

liquid quarts



stere

steres



tablespoon

tablespoons



teaspoon

teaspoons



register_ton

register tons



culeus

culei



amphora_quadrantal

amphora quadrantal



urna

urnae



modius_castrensis

modii castrensis



modius

modii



semimodius

semimodii



congius

congii



sextarius

sextarii



hemina

heminae



quartarius

quartarii



acetabulum

acetabula



cyathus

cyathi



ligula

ligula

Implementations



impl Units

pub fn abbreviation(&self) -> &'static str

Unit abbreviation.

pub fn singular(&self) -> &'static str

Unit singular description.

pub fn plural(&self) -> &'static str

Unit plural description.